@@ -35,13 +35,17 @@ module Gitlab
       def max_commit_or_tag_message_size
         @max_commit_or_tag_message_size ||= ENV['GITALY_RUBY_MAX_COMMIT_OR_TAG_MESSAGE_SIZE'].to_i
       end
+
+      def rugged_git_config_search_path
+        @rugged_git_config_search_path ||= ENV['GITALY_RUGGED_GIT_CONFIG_SEARCH_PATH']
+      end
     end
 
     class GitlabShell
       include TestSetup
 
       def path
-        @path ||= ENV['GITALY_GITLAB_SHELL_DIR']
+        @path ||= ENV['GITLAB_SHELL_DIR'] || ENV['GITALY_GITLAB_SHELL_DIR']
       end
 
       def git_timeout
@@ -52,8 +56,12 @@ module Gitlab
     class Gitaly
       include TestSetup
 
-      def client_path
-        @client_path ||= ENV['GITALY_RUBY_GITALY_BIN_DIR']
+      def bin_dir
+        @bin_dir ||= ENV['GITALY_RUBY_GITALY_BIN_DIR']
+      end
+
+      def ruby_dir
+        @ruby_dir ||= ENV['GITALY_RUBY_DIR']
       end
 
       def rbtrace_enabled?
